/** Copyright  2003 by Jean-Hugues de Raigniac <jhraigniac@workingfrog.org>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package org.workingfrog.i18n.swing;

import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.JMenuItem;

import org.workingfrog.i18n.util.LocaleEvent;
import org.workingfrog.i18n.util.LocaleListener;
import org.workingfrog.i18n.util.Translator;

/**
 * i18n version of javax.swing.JMenuItem
 *
 * @author Jean-Hugues de Raigniac
 */
public class I18NJMenuItem extends JMenuItem implements LocaleListener {

     /** i18n key */
    private String i18nKey = "menu.error";

    /**
     * Override javax.swing.JMenuItem.JMenuItem ().
     */
    public I18NJMenuItem () {
        super();
    }

    /**
     * Override javax.swing.JMenuItem.JMenuItem (java.lang.String).
     *
     * @param i18nKey i18n bundle key
     */
    public I18NJMenuItem (String i18nKey) {
        this(i18nKey, (Icon) null);
    }

    /**
     * Override javax.swing.JMenuItem.JMenuItem (javax.swing.Action).
     *
     * @param action action
     */
    public I18NJMenuItem (Action action) {
        this();
        setAction(action);
//        if (action instanceof LocaleListener) {
//            this.i18nKey = ((I18NAction) action).getKey();
//            setText(Translator.checkValue(actionBundle, i18nKey, this));
//            Translator.checkKey(i18nKey, this);
//        }
    }

    protected void configurePropertiesFromAction(Action a) {
    setText((a!=null ? Translator.checkValue((String)a.getValue(Action.NAME), this):null));
    setIcon((a!=null?(Icon)a.getValue(Action.SMALL_ICON):null));
    setEnabled((a!=null?a.isEnabled():true));
    setToolTipText((a!=null ? Translator.checkValue((String)a.getValue(Action.SHORT_DESCRIPTION), this):null));    
        if (a != null)  {
            Integer i = (Integer)a.getValue(Action.MNEMONIC_KEY);
            if (i != null)
                setMnemonic(i.intValue());
        }
    }

    /**
     * Override
     * javax.swing.JMenuItem.JMenuItem (java.lang.String, javax.swing.Icon).
     *
     * @param i18nKey i18n bundle key
     * @param icon icon
     */
    public I18NJMenuItem (String i18nKey, Icon icon) {
        super(Translator.checkValue(i18nKey, new I18NJMenuItem()), icon);
        Translator.checkKey(i18nKey, this);
        this.i18nKey = i18nKey;
    }

    /**
     * Override javax.swing.AbstractButton.setText(java.lang.String).
     *
     * @param i18nKey i18n bundle key
     */
    /*public void setText (String i18nKey) {
        if (i18nKey != null) {
            super.setText(Translator.checkValue(menuBundle, i18nKey, this));
        }
    }*/

    /**
     * Updates Action.NAME or JMenuItem label with a localized version
     * of i18nKey.
     *
     * @param event contains the new Locale
     */
    public void localeChanged (LocaleEvent event) {
        Action action = getAction();
        if (action != null) {
            if (action instanceof LocaleListener) {
                ((LocaleListener) action).localeChanged(event);
            }
        } else {
            setText(Translator.checkValue(i18nKey, this));
        }
    }
}
